#include "main_commands.hpp"

#include "utils/directories.hpp"
#include "utils/utils.hpp"
#include "utils/readmes.hpp"
#include "config.hpp"
#include <iostream>

namespace dropshell {

namespace main_commands {

int init(const std::vector<std::string> &args)
{
    dropshell::config *cfg = dropshell::get_global_config();
    std::string lcd;

    if (args.size() < 3) {
        std::cerr << "Error: init command requires a directory argument" << std::endl;
        return 1;
    }
    try {
        if (!cfg->add_local_config_directory(args[2])) 
        return 1; // error already reported

        cfg->save_config();
        std::cout << "Config directory added: " << cfg->get_local_config_directories().back() << std::endl;
        dropshell::create_readme_local_config_dir(cfg->get_local_config_directories().back());
        
            if (cfg->get_local_config_directories().size() ==1)
                std::cout << "DropShell is now initialised and you can add a server with 'dropshell create-server <server-name>'" << std::endl;
            else
            {
                std::cout << "DropShell will now use all of the following directories for configuration:" << std::endl;
                for (const auto& dir : cfg->get_local_config_directories()) {
                    std::cout << "  " << dir << std::endl;
                }
                std::cout << "You can edit the config file manually at: " << dropshell::get_local_dropshell_config_path() << std::endl;
            }
            return 0;
        } catch (const std::exception& e) {
            std::cerr << "Error in init: " << e.what() << std::endl;
        return 1;
    }
}

} // namespace main_commands

} // namespace dropshell
